==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24SplitPaneBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$SplitPaneBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78e8b189e6282166 javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct {
	jint	SUPPRESS__5fBOTTOM;
	jint	SUPPRESS__5fLEFT;
	jint	SUPPRESS__5fRIGHT;
	jint	SUPPRESS__5fTOP;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *);
extern jboolean _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *);
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$paintRect$5f554680c41222c6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jboolean, jint, jint, struct _jc_java_awt_Rectangle$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$paintRect$5f554680c41222c6;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *);
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
	void	(*paintRect$5f554680c41222c6)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jboolean, jint, jint, struct _jc_java_awt_Rectangle$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs {
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*shadow;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24SplitPaneBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$SplitPaneBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78e8b189e6282166 javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct {
	jint	SUPPRESS__5fBOTTOM;
	jint	SUPPRESS__5fLEFT;
	jint	SUPPRESS__5fRIGHT;
	jint	SUPPRESS__5fTOP;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$_init$1d46384a8c5f805d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$isBorderOpaque$9c9622032557868c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method$paintRect$5f554680c41222c6(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jboolean, jint, jint, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$isBorderOpaque$9c9622032557868c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$paintBorder$4a79b2eae89db578;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$method_info$paintRect$5f554680c41222c6;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	jboolean	(*isBorderOpaque$9c9622032557868c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
	void	(*paintRect$5f554680c41222c6)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object *, struct _jc_java_awt_Graphics$object *, jint, jboolean, jint, jint, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs {
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*shadow;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24SplitPaneBorder_H_ */
